#SEARCH API


This is a simple api that takes query input from user and results top 10 urls from google search.


##Installation


Run the following to install


pip install -i https://test.pypi.org/simple/searchapi


##usage 


After installation you have to copy the location of installed package.


After that run python "path"\searchapi\__init__.py


Application will be run on https://127.0.0.1:5000 which is same as localhost:5000


#Prompt user to enter the query to search


searchquery()


enter to search:
cd

#results

